const express = require('express');
const axios = require('axios');
const firebaseAdmin = require('firebase-admin');

const app = express();
const port = process.env.PORT || 3001;

const serviceAccount = require('./firebase/serviceAccountKey.json');
firebaseAdmin.initializeApp({
    credential: firebaseAdmin.credential.cert(serviceAccount),
    databaseURL: 'https://your-project-id.firebaseio.com'
});

const firestore = firebaseAdmin.firestore();
const weatherDataCollection = firestore.collection('weatherData');

const fetchDeviceAndStore = async (farmId, deviceId) => {
    try {
        const url = `http://192.168.73.130/api/data/${deviceId}`;
        const response = await axios.get(url);
        const weatherData = response.data;
        
        const { humidity, temperature } = weatherData;

        const timestamp = new Date().toISOString();
        await weatherDataCollection.doc(farmId).set({
            climateData: {
                [timestamp]: { humidity, temperature }
            }
        }, { merge: true });
    } catch (error) {
        console.log('Error fetching weather data:', error);
    }
};

const fetchInterval = 3600000; // 1 hour in milliseconds

setInterval(async () => {
    try {
        const deviceSnapshot = await firestore.collection('devices').get();
        deviceSnapshot.forEach((deviceDoc) => {
            const { deviceId } = deviceDoc.data();
            fetchDeviceAndStore(deviceDoc.id, deviceId);
        });
    } catch (error) {
        console.log('Error fetching devices:', error);
    }
}, fetchInterval);

app.listen(port, () => {
    console.log(`Server is running on http://localhost:${port}`);
});


//nodejs backend